# Python package initialization file.

'''
STEMDIFF package
----------------
Convert a 4D-STEM dataset to a single powder diffraction pattern.
'''

__version__ = "4.2.6"


